:description: Other choices for one time passwords in Python.

Alternatives
============

.. rst-class:: lead

    Here are some other OTP related libraries.

----

If you don't like ``otpauth``, you might like these.

pyca/cryptography
-----------------

**cryptography** includes both high level recipes and low level interfaces to common
cryptographic algorithms such as symmetric ciphers, message digests, and key
derivation functions.

- Author: Python Cryptographic Authority
- Source: https://github.com/pyca/cryptography
- Website: https://cryptography.io/
- Documentation: https://cryptography.io/en/latest/hazmat/primitives/twofactor/


PyOTP
-----

PyOTP is a Python library for generating and verifying one-time passwords.

- Author: Andrey Kislyuk
- Source: https://github.com/pyauth/pyotp
- Website: https://pyauth.github.io/pyotp/
